@@ -72,7 +72,7 @@ rmw_partial_dependencies <- function(model, df, variable, training_only = TRUE,
     
   # Check inputs
   df <- rmw_check_data(df, prepared = TRUE)
-  stopifnot(class(model) == "ranger")
+  stopifnot(inherits(model, "ranger"))
   
   # Default logic for cpu cores
   n_cores <- as.integer(n_cores)
@@ -85,7 +85,9 @@ rmw_partial_dependencies <- function(model, df, variable, training_only = TRUE,
   
   # Message to user
   if (verbose) {
-    cli::cli_alert_info("{str_date_formatted()}: Predicting `{length(variable)}` variable{?s}...")
+    cli::cli_alert_info(
+      "{str_date_formatted()}: Predicting `{length(variable)}` variable{?s}..."
+    )
   }
   
   # Calculate the partial dependencies
@@ -136,7 +138,7 @@ rmw_partial_dependencies_worker <- function(model, df, variable, training_only,
   
   # Catch factors, usually weekday
   if ("factor" %in% class(df_predict$value)) {
-    df_predict$value <- as.integer(df_predict$value)
+    df_predict$value <- as.integer(as.character(df_predict$value))
   }
   
   return(df_predict)
