@@ -63,11 +63,11 @@ rmw_train_model <- function(df, variables, n_trees = 300, mtry = NULL,
   
   # Check arguments
   if (anyDuplicated(variables) != 0) {
-    stop("`variables` contains duplicate elements.", call. = FALSE)
+    cli::cli_abort("`variables` contains duplicate elements.")
   }
   
   if (!all(variables %in% names(df))) {
-    stop("`variables` given are not within input data frame.", call. = FALSE)
+    cli::cli_abort("`variables` given are not within input data frame.")
   }
   
   # Check input dataset
@@ -83,7 +83,9 @@ rmw_train_model <- function(df, variables, n_trees = 300, mtry = NULL,
   n_cores <- as.integer(n_cores)
   n_cores <- if_else(is.na(n_cores), n_cores_default(), n_cores)
   
-  if (verbose) message(str_date_formatted(), ": Growing the forest...")
+  if (verbose) {
+    cli::cli_alert_info("{str_date_formatted()}: Growing the forest...")
+  }
   
   # Train the model/grow the forest
   model <- ranger::ranger(
